Tools for working with Data Packages and CKAN
=============================================

| |Travis|
| |Coveralls|
| |PyPi|
| |SemVer|
| |Gitter|

Install
-------

::

    # clone the repo and install it with pip

    git clone https://github.com/frictionlessdata/ckan-datapackage-tools.git
    pip install -e .

Usage
-----

.. |Travis| image:: https://img.shields.io/travis/frictionlessdata/ckan-datapackage-tools/master.svg
   :target: https://travis-ci.org/frictionlessdata/ckan-datapackage-tools
.. |Coveralls| image:: http://img.shields.io/coveralls/frictionlessdata/ckan-datapackage-tools/master.svg
   :target: https://coveralls.io/r/frictionlessdata/ckan-datapackage-tools?branch=master
.. |PyPi| image:: https://img.shields.io/pypi/v/ckan-datapackage-tools.svg
   :target: https://pypi.python.org/pypi/ckan-datapackage-tools
.. |SemVer| image:: https://img.shields.io/badge/versions-SemVer-brightgreen.svg
   :target: http://semver.org/
.. |Gitter| image:: https://img.shields.io/gitter/room/frictionlessdata/chat.svg
   :target: https://gitter.im/frictionlessdata/chat
